@@ -5,7 +5,7 @@ class MissionFfiCoordsObjectInfo(ObjectInfo):
     Implementation of ObjectInfo to be used to characterize long-cadence objects from TESS by providing the RA and Dec.
     """
     def __init__(self, ra, dec, sectors, author=None, cadence=None, initial_mask=None, initial_transit_mask=None,
-                 initial_detrend_period=None, star_info=None, aperture_file=None):
+                 initial_detrend_period=None, star_info=None, aperture_file=None, eleanor_corr_flux="pca_flux"):
         """
         @param ra: the objects right ascension.
         @param dec: the objects declination.
@@ -15,6 +15,7 @@ class MissionFfiCoordsObjectInfo(ObjectInfo):
         @param star_info: input star information
         @param aperture_file: the file containing 1s and 0s specifying the user selected aperture
         from the initial light curve before processing.
+        @param eleanor_corr_flux the corrected flux name to be used from ELEANOR
         """
         super().__init__(initial_mask, initial_transit_mask, initial_detrend_period, star_info, aperture_file)
         self.ra = ra
@@ -22,6 +23,7 @@ class MissionFfiCoordsObjectInfo(ObjectInfo):
         self.sectors = sectors
         self.cadence = cadence
         self.author = author
+        self.eleanor_corr_flux = eleanor_corr_flux
 
     def sherlock_id(self):
         return str(self.ra) + "_" + str(self.dec) + "_FFI_" + str(self.sectors)
